MyApp = function()
{
	var container = null;
	var view = null;
	var model = null;
	var cmdSave = null;

	function init()
	{
		container = document.createElement("div");
		Fit.Dom.AddClass(container, "MyApp");

		// Load StyleSheet
		Fit.Loader.LoadStyleSheet("View.css");

		// Load View (HTML template)
		view = new Fit.Template(true);
		view.LoadUrl("View.html", function(sender)
		{
			// View loaded and ready to be populated.
			view.Render(container);
			populateTemplate();
		});

		// Load Model
		var req = new Fit.Http.JsonRequest("GetEmployees.php");
		req.OnSuccess(function(sender)
		{
			// Data loaded and ready to be added to View.
			model = req.GetResponseJson();
			populateTemplate();
		});
		req.Start();

		// Create save button
		cmdSave = new Fit.Controls.Button("SaveUsers");
		cmdSave.Title("Save changes");
		cmdSave.Icon("save");
		cmdSave.Type(Fit.Controls.Button.Type.Success);
		cmdSave.Enabled(false);
		cmdSave.OnClick(function(sender)
		{
			saveUsers();
		});
	}

	function populateTemplate()
	{
		// Add data from Model to View

		if (view.Content === null || model === null)
			return; // Skip, either View or Model has not been loaded yet

		Fit.Array.ForEach(model, function(user)
		{
			// Add item to <!-- LIST Users --> block in View
			var u = view.Content.Users.AddItem();

			// Update placeholders defined in View for our new user
			u.Id = user.Id;
			u.Name = createInput(user.Name);
			u.Email = createInput(user.Email);
			u.Department = createInput(user.Department);

			// Associate user from Model with user in View.
			// We need this reference later when sending
			// changes to the server (see saveUsers()).
			u._userObject = user;
		});
		
		view.Content.SaveButton = cmdSave.GetDomElement();
		
		view.Update(); // Push updates to DOM
		cmdSave.Enabled(true);
	}

	function createInput(value)
	{
		// Create edit control
		var input = new Fit.Controls.Input(Fit.Data.CreateGuid());
		input.Value(value);

		// Get DOM element representing edit control.
		// Associate edit control with DOM element.
		// We need the reference to the edit control when
		// saving changes to the server (see saveUsers()).
		var elm = input.GetDomElement();
		elm._control = input;

		return elm;
	}

	function saveUsers()
	{
		cmdSave.Enabled(false);

		// Loop through all users in View
		Fit.Array.ForEach(view.Content.Users.GetItems(), function(user)
		{
			// Update each user from our Model with
			// the value entered in the edit control.
			user._userObject.Name = user.Name._control.Value();
			user._userObject.Email = user.Email._control.Value();
			user._userObject.Department = user.Department._control.Value();
		});

		// Send the updated data to the server
		var req = new Fit.Http.JsonRequest("UpdateEmployees.php");
		req.SetData(model);
		req.OnSuccess(function(sender)
		{
			Fit.Controls.Dialog.Alert("Done - the server received the following data:<br><pre>" + req.GetResponseText() + "</pre>");
			cmdSave.Enabled(true);
		});
		req.Start();
	}

	this.Render = function(target)
	{
		Fit.Dom.Add(target, container);
	}

	init();
}
